import { AbstractBatchOperation, AbstractLevel } from "abstract-level";
import { Cache } from "@peerbit/cache";
export type LevelBatchOptions = {
    interval: number;
    queueMaxBytes: number;
    cacheMaxBytes: number;
    onError?: (error: any) => void;
};
export type LazyLevelOptions = {
    batch?: LevelBatchOptions;
};
type MaybePromise<T> = Promise<T> | T;
export interface SimpleLevel {
    status(): MaybePromise<"opening" | "open" | "closing" | "closed">;
    close(): Promise<void>;
    open(): Promise<void>;
    get(key: string): Promise<Uint8Array | undefined>;
    put(key: string, value: Uint8Array): any;
    del(key: any): Promise<void>;
    sublevel(name: string): MaybePromise<SimpleLevel>;
    clear(): Promise<void>;
    idle?(): Promise<void>;
}
declare class TXQueue {
    readonly opts: LevelBatchOptions;
    readonly store: AbstractLevel<any, any, any>;
    queue: AbstractBatchOperation<AbstractLevel<any, string, Uint8Array>, string, Uint8Array>[];
    currentSize: number;
    txPromise?: Promise<void>;
    private _interval?;
    tempStore: Cache<Uint8Array>;
    tempDeleted: Set<string>;
    constructor(opts: LevelBatchOptions, store: AbstractLevel<any, any, any>);
    open(): void;
    add(tx: AbstractBatchOperation<AbstractLevel<any, string, Uint8Array>, string, Uint8Array>): Promise<void>;
    processTxQueue(): Promise<void>;
    idle(): Promise<void>;
    clear(): void;
    close(): Promise<void>;
}
export default class LazyLevel implements SimpleLevel {
    private _store;
    private _opts?;
    private _sublevels;
    txQueue?: TXQueue;
    constructor(store: AbstractLevel<any, any, any>, opts?: LazyLevelOptions | {
        batch: boolean;
    });
    status(): "opening" | "open" | "closing" | "closed";
    idle(): Promise<void>;
    close(): Promise<void>;
    open(): Promise<void>;
    get(key: string): Promise<Uint8Array | undefined>;
    getByPrefix(prefix: string): Promise<Uint8Array[]>;
    clear(clearStore?: boolean): Promise<void>;
    deleteByPrefix(prefix: string): Promise<void>;
    put(key: string, value: Uint8Array): Promise<void>;
    del(key: string): Promise<void>;
    delAll(keys: string[]): Promise<void>;
    sublevel(name: string): Promise<LazyLevel>;
}
export {};
